import { ref} from 'vue';

export const isUndefined = (val: any): val is undefined => val === undefined;
export const isBoolean = (val: any): val is boolean => typeof val === 'boolean';
export const isNumber = (val: any): val is number => typeof val === 'number';



export const isFilledArray = (val: any) => Array.isArray(val) && val.length > 0;

/**
 *
 * @param _comp 组件构造函数
 * @returns 组件 ref
 * @example const formRef = useCompRef(ElForm);
 */
export const useCompRef = <T extends abstract new (...args: any) => any>(_comp: T) => ref<InstanceType<T>>();


/**
 * 深层次 Partial
 */
export type DeepPartial<T> = T extends object ? {
    [P in keyof T]?: DeepPartial<T[P]>;
} : T;


